Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(798)

Unified Diff: content/browser/renderer_host/render_widget_helper.h

Issue 8498036: Delay UpdateRect until the SwapBuffers callback when accelerated compositing is on. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: allow multiple update messages in flight Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/render_widget_helper.h
diff --git a/content/browser/renderer_host/render_widget_helper.h b/content/browser/renderer_host/render_widget_helper.h
index 605a317145d9e906cd470414786a4184c1953668..766566aaa3b5ef42eda7f997c694a5dfbb317f27 100644
--- a/content/browser/renderer_host/render_widget_helper.h
+++ b/content/browser/renderer_host/render_widget_helper.h
@@ -6,6 +6,7 @@
#define CONTENT_BROWSER_RENDERER_HOST_RENDER_WIDGET_HELPER_H_
#pragma once
+#include <deque>
#include <map>
#include "base/atomic_sequence_num.h"
@@ -160,8 +161,9 @@ class RenderWidgetHelper
friend class UpdateMsgProxy;
friend class base::RefCountedThreadSafe<RenderWidgetHelper>;
- // Map from render_widget_id to live PaintMsgProxy instance.
- typedef base::hash_map<int, UpdateMsgProxy*> UpdateMsgProxyMap;
+ typedef std::deque<UpdateMsgProxy*> UpdateMsgProxyQueue;
+ // Map from render_widget_id to a queue of live PaintMsgProxy instances.
+ typedef base::hash_map<int, UpdateMsgProxyQueue > UpdateMsgProxyMap;
~RenderWidgetHelper();
« no previous file with comments | « content/browser/renderer_host/render_message_filter.cc ('k') | content/browser/renderer_host/render_widget_helper.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698